@@ -21,6 +21,8 @@ import zmq.green as zmq
 import gevent
 from gevent import Greenlet
 
+import beeswarm
+import beeswarm.shared
 from beeswarm.server.db import database_setup
 from beeswarm.server.db.entities import Client, BaitSession, Session, Honeypot, Authentication, Classification, \
     Transcript
@@ -32,21 +34,31 @@ logger = logging.getLogger(__name__)
 
 
 class SessionPersister(gevent.Greenlet):
-    def __init__(self):
+    def __init__(self, clear_sessions=False):
         Greenlet.__init__(self)
-        ctx = zmq.Context()
+        db_session = database_setup.get_session()
+        # clear all pending sessions on startup, pending sessions on startup
+        pending_classification = db_session.query(Classification).filter(Classification.type == 'pending').one()
+        pending_deleted = db_session.query(Session).filter(Session.classification == pending_classification).delete()
+        db_session.commit()
+        logging.info('Cleaned {0} pending sessions on startup'.format(pending_deleted))
+        if clear_sessions:
+            count = db_session.query(Session).delete()
+            logging.info('Deleting {0} sessions on startup.'.format(count))
+            db_session.commit()
+        ctx = beeswarm.shared.zmq_context
         self.subscriber_sessions = ctx.socket(zmq.SUB)
-        self.subscriber_sessions.connect('ipc://sessionPublisher')
+        self.subscriber_sessions.connect('inproc://sessionPublisher')
         self.subscriber_sessions.setsockopt(zmq.SUBSCRIBE, '')
         self.first_cfg_received = gevent.event.Event()
         self.config = None
 
     def config_subscriber(self):
-        ctx = zmq.Context()
+        ctx = beeswarm.shared.zmq_context
         subscriber_config = ctx.socket(zmq.SUB)
-        subscriber_config.connect('ipc://configPublisher')
+        subscriber_config.connect('inproc://configPublisher')
         subscriber_config.setsockopt(zmq.SUBSCRIBE, '')
-        send_zmq_request('ipc://configCommands', Messages.PUBLISH_CONFIG)
+        send_zmq_request('inproc://configCommands', Messages.PUBLISH_CONFIG)
 
         while True:
             poller = zmq.Poller()
