@@ -25,11 +25,10 @@ from zmq.auth.ioloop import IOLoopAuthenticator
 from zmq.auth.certs import load_certificate
 
 import beeswarm
-from beeswarm.server.webapp import app
 from beeswarm.server.webapp.auth import Authenticator
 from beeswarm.shared.helpers import drop_privileges, send_zmq_request
 from beeswarm.server.misc.scheduler import Scheduler
-from beeswarm.shared.helpers import find_offset, create_self_signed_cert, generate_cert_digest
+from beeswarm.shared.helpers import create_self_signed_cert, generate_cert_digest
 from beeswarm.shared.asciify import asciify
 from beeswarm.server.db.session_persister import SessionPersister
 from beeswarm.server.misc.config_actor import ConfigActor
@@ -51,26 +50,30 @@ class Server(object):
         :param config_arg: Beeswarm configuration dictionary, None if not configuration was supplied.
         """
         customize = kwargs['customize']
+        if 'clear_db' in kwargs:
+            clear_sessions = kwargs['clear_db']
+        else:
+            clear_sessions = True
 
         self.work_dir = work_dir
         self.config_file = 'beeswarmcfg.json'
-
         if config is None:
             Server.prepare_environment(work_dir, customize)
             with open(os.path.join(work_dir, self.config_file), 'r') as config_file:
                 self.config = json.load(config_file, object_hook=asciify)
         else:
             self.config = config
-
         # list of all self-running (actor) objects that receive or send
         # messages on one or more zmq queues
         self.actors = []
 
+        gevent.spawn(self.message_proxy, work_dir)
         config_actor = ConfigActor(self.config_file, work_dir)
         config_actor.start()
         self.actors.append(config_actor)
 
-        persistanceActor = SessionPersister()
+        database_setup.setup_db(os.path.join(self.config['sql']['connection_string']))
+        persistanceActor = SessionPersister(clear_sessions)
         persistanceActor.start()
         self.actors.append(persistanceActor)
         gevent.sleep()
@@ -79,12 +82,11 @@ class Server(object):
         self.greenlets = []
         self.started = False
 
-        database_setup.setup_db(os.path.join(self.config['sql']['connection_string']))
+        from beeswarm.server.webapp import app
         self.app = app.app
         self.app.config['CERT_PATH'] = self.config['ssl']['certpath']
         self.authenticator = Authenticator()
         self.authenticator.ensure_default_user()
-        gevent.spawn(self.message_proxy, work_dir)
 
     # distributes messages between external and internal receivers and senders
     def message_proxy(self, work_dir):
@@ -93,8 +95,6 @@ class Server(object):
         drone_data_outbound is for commands to the drones, topic must either be a drone ID or all for sending
                             a broadcast message to all drones
         """
-        ctx = zmq.Context()
-
         public_keys_dir = os.path.join(work_dir, 'certificates', 'public_keys')
         secret_keys_dir = os.path.join(work_dir, 'certificates', 'private_keys')
 
@@ -108,13 +108,13 @@ class Server(object):
         # external interfaces for communicating with drones
         server_secret_file = os.path.join(secret_keys_dir, 'beeswarm_server.pri')
         server_public, server_secret = load_certificate(server_secret_file)
-        drone_data_inbound = ctx.socket(zmq.PULL)
+        drone_data_inbound = beeswarm.shared.zmq_context.socket(zmq.PULL)
         drone_data_inbound.curve_secretkey = server_secret
         drone_data_inbound.curve_publickey = server_public
         drone_data_inbound.curve_server = True
         drone_data_inbound.bind('tcp://*:{0}'.format(self.config['network']['zmq_port']))
 
-        drone_data_outbound = ctx.socket(zmq.PUB)
+        drone_data_outbound = beeswarm.shared.zmq_context.socket(zmq.PUB)
         drone_data_outbound.curve_secretkey = server_secret
         drone_data_outbound.curve_publickey = server_public
         drone_data_outbound.curve_server = True
@@ -122,12 +122,12 @@ class Server(object):
 
         # internal interfaces
         # all inbound session data from drones will be replayed in this socket
-        sessionPublisher = ctx.socket(zmq.PUB)
-        sessionPublisher.bind('ipc://sessionPublisher')
+        sessionPublisher = beeswarm.shared.zmq_context.socket(zmq.PUB)
+        sessionPublisher.bind('inproc://sessionPublisher')
 
         # all commands received on this will be published on the external interface
-        drone_command_receiver = ctx.socket(zmq.PULL)
-        drone_command_receiver.bind('ipc://droneCommandReceiver')
+        drone_command_receiver = beeswarm.shared.zmq_context.socket(zmq.PULL)
+        drone_command_receiver.bind('inproc://droneCommandReceiver')
 
         poller = zmq.Poller()
         poller.register(drone_data_inbound, zmq.POLLIN)
@@ -179,12 +179,15 @@ class Server(object):
                     logging.debug('Drone {0} reported ip: {1}'.format(drone_id, ip_address))
                     db_session = database_setup.get_session()
                     drone = db_session.query(Drone).filter(Drone.id == drone_id).one()
-                    drone.ip_address = ip_address
-                    db_session.add(drone)
-                    db_session.commit()
-                # drons want it's config transmitted
+                    if drone.ip_address != ip_address:
+                        drone.ip_address = ip_address
+                        db_session.add(drone)
+                        db_session.commit()
+                        send_zmq_request('inproc://configCommands', '{0} {1}'.format(Messages.DRONE_CONFIG_CHANGED,
+                                                                                     drone_id))
+                # drone want it's config transmitted
                 elif topic == Messages.DRONE_CONFIG:
-                    config_dict = send_zmq_request('ipc://configCommands', '{0} {1}'.format(Messages.DRONE_CONFIG,
+                    config_dict = send_zmq_request('inproc://configCommands', '{0} {1}'.format(Messages.DRONE_CONFIG,
                                                                                             drone_id))
                     drone_data_outbound.send('{0} {1} {2}'.format(drone_id, Messages.CONFIG, json.dumps(config_dict)))
                 else:
@@ -317,12 +320,12 @@ class Server(object):
                     zmq_command_port = int(zmq_port)
 
             # tmp actor while initializing
-            config_actor = ConfigActor('beeswarmcfg.json', work_dir)
+            config_actor = ConfigActor('beeswarmcfg.json', work_dir, True)
             config_actor.start()
-
-            context = zmq.Context()
+            context = beeswarm.shared.zmq_context
             socket = context.socket(zmq.REQ)
-            socket.connect('ipc://configCommands')
+            gevent.sleep()
+            socket.connect('inproc://configCommands')
             socket.send('{0} {1}'.format(Messages.GEN_ZMQ_KEYS, 'beeswarm_server'))
             result = socket.recv()
             if result.split(' ', 1)[0] == Messages.OK:
@@ -352,6 +355,5 @@ class Server(object):
 
             }
             )))
-
             socket.recv()
             config_actor.close()
