@@ -20,7 +20,6 @@ import os
 import random
 import shutil
 import string
-import tempfile
 import uuid
 from collections import namedtuple
 
@@ -36,12 +35,14 @@ from wtforms import HiddenField
 
 from beeswarm.server.webapp.auth import Authenticator
 import beeswarm
+import beeswarm.shared
 from forms import HoneypotConfigurationForm, NewClientConfigForm, LoginForm, SettingsForm
 from beeswarm.server.db import database_setup
 from beeswarm.server.db.entities import Client, BaitSession, Session, Honeypot, User, BaitUser, Transcript, Drone, \
     Authentication
 from beeswarm.shared.helpers import send_zmq_request_socket
 from beeswarm.shared.message_enum import Messages
+import beeswarm
 
 
 def is_hidden_field_filter(field):
@@ -68,17 +69,17 @@ first_cfg_received = gevent.event.Event()
 # keys used for adding new drones to the system
 drone_keys = []
 
-context = zmq.Context()
+context = beeswarm.shared.zmq_context
 config_actor_socket = context.socket(zmq.REQ)
-config_actor_socket.connect('ipc://configCommands')
+config_actor_socket.connect('inproc://configCommands')
 request_lock = gevent.lock.RLock()
 
 
 def config_subscriber():
     global config
-    ctx = zmq.Context()
+    ctx = beeswarm.shared.zmq_context
     subscriber_socket = ctx.socket(zmq.SUB)
-    subscriber_socket.connect('ipc://configPublisher')
+    subscriber_socket.connect('inproc://configPublisher')
     subscriber_socket.setsockopt(zmq.SUBSCRIBE, Messages.CONFIG_FULL)
     while True:
         poller = zmq.Poller()
@@ -96,6 +97,7 @@ def send_config_request(request):
     global config_actor_socket
     request_lock.acquire()
     try:
+        gevent.sleep()
         return send_zmq_request_socket(config_actor_socket, request)
     finally:
         request_lock.release()
@@ -192,6 +194,7 @@ def set_honeypot_mode(drone_id):
         db_session.delete(drone)
         db_session.commit()
         honeypot = Honeypot(id=drone_id)
+        honeypot.ip_address = drone.ip_address
         db_session.add(honeypot)
         db_session.commit()
         return ''
@@ -209,6 +212,7 @@ def set_client_mode(drone_id):
         db_session.delete(drone)
         db_session.commit()
         client = Client(id=drone_id)
+        client.ip_address = drone.ip_address
         db_session.add(client)
         db_session.commit()
         return ''
@@ -378,7 +382,9 @@ def drone_key(key):
         drone = Drone(id=drone_id)
         db_session.add(drone)
         db_session.commit()
+        print 'asking for config'
         config_json = send_config_request('{0} {1}'.format(Messages.DRONE_CONFIG, drone_id))
+        print 'got config'
         return json.dumps(config_json)
 
 
@@ -608,9 +614,9 @@ def settings():
 
 
 def update_config(options):
-    context = zmq.Context()
+    context = beeswarm.shared.zmq_context
     socket = context.socket(zmq.REQ)
-    socket.connect('ipc://configCommands')
+    socket.connect('inproc://configCommands')
     socket.send('{0} {1}'.format(Messages.SET, json.dumps(options)))
     reply = socket.recv()
     if reply != Messages.OK:
