@@ -30,6 +30,8 @@ import zmq.green as zmq
 import gevent
 import requests
 from beeswarm.shared.asciify import asciify
+import beeswarm
+import beeswarm.shared
 
 from beeswarm.shared.message_enum import Messages
 
@@ -148,9 +150,13 @@ def get_most_likely_ip():
         # TODO: continue if network interface is down
         addresses = netifaces.ifaddresses(interface_name)
         if netifaces.AF_INET in addresses:
-            if 'addr' in addresses:
-                logger.debug('Found likely IP {0} on IF {1}'.format(interface_name, addresses['addr']))
-                return addresses['addr']
+            for item in addresses[netifaces.AF_INET]:
+                if 'addr' in item:
+                    logger.debug('Found likely IP {0} on interface {1}'.format(item['addr'], interface_name))
+                    return item['addr']
+                    # well, actually the interface could have more IP's... But for now we assume that the IP
+                    # we want is the first in the list on the IF.
+                    break
 
     return '127.0.0.1'
 
@@ -173,7 +179,7 @@ def get_config_dict(configfile):
 
 # for occasional req/resp
 def send_zmq_request(actor_url, request):
-    context = zmq.Context()
+    context = beeswarm.shared.zmq_context
     socket = context.socket(zmq.REQ)
     socket.connect(actor_url)
     socket.send(request)
@@ -199,7 +205,7 @@ def send_zmq_request_socket(socket, request):
 
 # for occasional zmq pushes
 def send_zmq_push(actor_url, data):
-    context = zmq.Context()
+    context = beeswarm.shared.zmq_context
     socket = context.socket(zmq.PUSH)
     socket.connect(actor_url)
     socket.send(data)
